create_boundary_plot: Render a decision boundary plot for the Shiny app

View source: R/app.R

create_boundary_plotR Documentation

Render a decision boundary plot for the Shiny app

Description

Render a decision boundary plot for the Shiny app

Usage

create_boundary_plot(
  cb_mod,
  data,
  title,
  class_levels = NULL,
  class_colors = NULL,
  proj_matrix = NULL,
  proj_info = NULL,
  zoom_x = NULL,
  zoom_y = NULL,
  show_probs = FALSE,
  resolution = 100,
  predict_args = list(),
  n_outliers = 0,
  highlight_outliers = TRUE,
  slice_x = NULL,
  slice_y = NULL
)

Arguments

cb_mod

A classbound_model object.

data

The training data to overlay.

title

The title of the plot.

class_levels

The factor levels for the classes.

proj_matrix

Optional projection matrix.

proj_info

Optional list with center and scale for projection.

zoom_x

Optional x-axis limits.

zoom_y

Optional y-axis limits.

show_probs

Whether to show probability gradients.

resolution

The grid resolution.

slice_x

Optional. Feature name to use for the X axis in 2D Slice mode.

slice_y

Optional. Feature name to use for the Y axis in 2D Slice mode.

Value

A ggplot object.


classbound documentation built on Sept. 30, 2026, 5:13 p.m.