generate_outlier: Generate a deterministic extreme outlier based on dataset...

View source: R/app.R

generate_outlierR Documentation

Generate a deterministic extreme outlier based on dataset bounds

Description

Generate a deterministic extreme outlier based on dataset bounds

Usage

generate_outlier(data, class_label, magnitude, target_col = "Sim", index = 1)

Arguments

data

A data frame containing the features and target column.

class_label

The class label to assign to the outlier.

magnitude

A numeric value indicating how far outside the bounding box to place the outlier.

target_col

The name of the target column in the data.

index

An integer index used to cycle through bounding box corners.

Value

A one-row data frame with the generated outlier.


classbound documentation built on Sept. 30, 2026, 5:13 p.m.