predict_adapter.PPtreeExtclass: Predict using a fitted PPtreeExt model

View source: R/predict_adapters.R

predict_adapter.PPtreeExtclassR Documentation

Predict using a fitted PPtreeExt model

Description

Adapter function to generate standardized predictions from a PPtreeExt model.

Usage

## S3 method for class 'PPtreeExtclass'
predict_adapter(model, newdata, ...)

Arguments

model

A fitted PPtreeExtclass object.

newdata

A data frame of new observations to predict on.

...

Additional arguments passed to predict().

Value

A list containing class (predicted labels) and probs (probabilities, NULL for pptree).


classbound documentation built on Sept. 30, 2026, 5:13 p.m.