predict_adapter.PPtreeclass: Predict using a fitted PPtreeViz model

View source: R/predict_adapters.R

predict_adapter.PPtreeclassR Documentation

Predict using a fitted PPtreeViz model

Description

Adapter function to generate standardized predictions from a PPtreeViz model.

Usage

## S3 method for class 'PPtreeclass'
predict_adapter(model, newdata, ...)

Arguments

model

A fitted PPtreeclass object.

newdata

A data frame of new observations to predict on.

...

Additional arguments passed to predict().

Value

A list containing class (predicted labels) and probs (probabilities, NULL for PPtreeViz).


classbound documentation built on Sept. 30, 2026, 5:13 p.m.