| create_boundary_plot | R Documentation |
Render a decision boundary plot for the Shiny app
create_boundary_plot(
cb_mod,
data,
title,
class_levels = NULL,
class_colors = NULL,
proj_matrix = NULL,
proj_info = NULL,
zoom_x = NULL,
zoom_y = NULL,
show_probs = FALSE,
resolution = 100,
predict_args = list(),
n_outliers = 0,
highlight_outliers = TRUE,
slice_x = NULL,
slice_y = NULL
)
cb_mod |
A classbound_model object. |
data |
The training data to overlay. |
title |
The title of the plot. |
class_levels |
The factor levels for the classes. |
proj_matrix |
Optional projection matrix. |
proj_info |
Optional list with center and scale for projection. |
zoom_x |
Optional x-axis limits. |
zoom_y |
Optional y-axis limits. |
show_probs |
Whether to show probability gradients. |
resolution |
The grid resolution. |
slice_x |
Optional. Feature name to use for the X axis in 2D Slice mode. |
slice_y |
Optional. Feature name to use for the Y axis in 2D Slice mode. |
A ggplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.