| explorapp | R Documentation |
Shiny app to visually explore and compare classification boundaries for built-in, custom, and tidymodels algorithms in 2D
explorapp(data = NULL, target_col = NULL, custom_models = list())
data |
Optional data frame to import directly into the app. |
target_col |
Optional string specifying the column in |
custom_models |
A list of custom models to inject into the app's comparison UI. Each element should be a named list containing at least |
No return value, called for side effects. Shinyapp is launched.
if (interactive()) {
# Launch with default models
explorapp()
# Launch with a custom SVM model
explorapp(custom_models = list(
"SVM" = list(
fn = e1071::svm,
args = list(kernel = "linear")
)
))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.