| generate_outlier | R Documentation |
Generate a deterministic extreme outlier based on dataset bounds
generate_outlier(data, class_label, magnitude, target_col = "Sim", index = 1)
data |
A data frame containing the features and target column. |
class_label |
The class label to assign to the outlier. |
magnitude |
A numeric value indicating how far outside the bounding box to place the outlier. |
target_col |
The name of the target column in the data. |
index |
An integer index used to cycle through bounding box corners. |
A one-row data frame with the generated outlier.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.