View source: R/predict_adapters.R
| predict_adapter.PPtreeExtclass | R Documentation |
Adapter function to generate standardized predictions from a PPtreeExt model.
## S3 method for class 'PPtreeExtclass'
predict_adapter(model, newdata, ...)
model |
A fitted |
newdata |
A data frame of new observations to predict on. |
... |
Additional arguments passed to |
A list containing class (predicted labels) and probs (probabilities, NULL for pptree).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.