View source: R/predict_adapters.R
| predict_adapter.pprf_classification | R Documentation |
Adapter function to generate standardized predictions from a ppforest2 model.
Developer Note: During development, an issue was observed with
ppforest2 v0.1.3 when training data is contiguous by class but
ordered so that the lowest class does not occur first (e.g.,
Class 3, Class 3, Class 1, Class 1). In this case, the underlying
C++ code can produce Grouping::init: partition must be rooted at row 0.
classbound does not reorder or otherwise modify the training data
specifically to avoid this behavior. If a future version of ppforest2
changes this behavior, no corresponding change to classbound is
expected to be necessary.
## S3 method for class 'pprf_classification'
predict_adapter(model, newdata, ...)
model |
A fitted |
newdata |
A data frame of new observations to predict on. |
... |
Additional arguments passed to |
A list containing class (predicted labels) and probs (probabilities).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.