summary.classbound: Summarize a classbound model

View source: R/classbound_methods.R

summary.classboundR Documentation

Summarize a classbound model

Description

For single models, delegates the summary function directly to the native model wrapped inside the classbound object. For multi-model objects (classbound_multi), it returns a summary of the contained models.

Usage

## S3 method for class 'classbound'
summary(object, ...)

## S3 method for class 'classbound_multi'
summary(object, ...)

Arguments

object

A classbound or classbound_multi object.

...

Additional arguments passed to the native model's summary method.

Value

The summary of the native model.


classbound documentation built on Sept. 30, 2026, 5:13 p.m.